==> gender-1.9.1-f4-1.17.1.jar: core/playerrenders.js <==
var ASMAPI=Java.type("net.minecraftforge.coremod.api.ASMAPI");
var Opcodes=Java.type('org.objectweb.asm.Opcodes');
var InsnList=Java.type('org.objectweb.asm.tree.InsnList');
var InsnNode=Java.type('org.objectweb.asm.tree.InsnNode');
var VarInsnNode=Java.type('org.objectweb.asm.tree.VarInsnNode');
var MethodInsnNode=Java.type('org.objectweb.asm.tree.MethodInsnNode');
var M0=ASMAPI.mapMethod("m_7546_");
var M0_DESC="(Lnet/minecraft/client/player/AbstractClientPlayer;Lcom/mojang/blaze3d/vertex/PoseStack;F)V";
var NUM_FOUND=0;
var NUM_PATCHED=0;
function log(message){
	print("[GenderCore]: "+message);
}
function initializeCoreMod(){
	return{
		"GenderCore-PlayerRenderer":{
			"target":{"type":"CLASS",'name':'net.minecraft.client.renderer.entity.player.PlayerRenderer'},
			"transformer": function(classNode){
				for each(var method in classNode.methods){
					if(method.name.equals(M0)&&method.desc.equals(M0_DESC)){
						NUM_FOUND++;
						var toInject=new InsnList();
						toInject.add(new VarInsnNode(Opcodes.ALOAD,1));
						toInject.add(new VarInsnNode(Opcodes.ALOAD,2));
						toInject.add(new MethodInsnNode(Opcodes.INVOKESTATIC,"com/github/ipixeli/gender/forge/client/GenderClient","onEvent","(Lnet/minecraft/client/player/AbstractClientPlayer;Lcom/mojang/blaze3d/vertex/PoseStack;)V"));
						toInject.add(new InsnNode(Opcodes.RETURN));
						method.instructions=toInject;
						NUM_PATCHED++;
					}//else if(method.name.equals("M0")) log(classNode.name+" - Didn't quite match: "+method.name+method.desc);
				}
				log("Found methods: "+NUM_FOUND+" of 1; Patched methods: "+NUM_PATCHED+" of 1");
				return classNode;
			}
		}
	};
}

==> gender-1.9.2-f5-1.18.2.jar: core/playerrenders.js <==
var ASMAPI=Java.type("net.minecraftforge.coremod.api.ASMAPI");
var Opcodes=Java.type('org.objectweb.asm.Opcodes');
var InsnList=Java.type('org.objectweb.asm.tree.InsnList');
var InsnNode=Java.type('org.objectweb.asm.tree.InsnNode');
var VarInsnNode=Java.type('org.objectweb.asm.tree.VarInsnNode');
var MethodInsnNode=Java.type('org.objectweb.asm.tree.MethodInsnNode');
var M0=ASMAPI.mapMethod("m_7546_");
var M0_DESC="(Lnet/minecraft/client/player/AbstractClientPlayer;Lcom/mojang/blaze3d/vertex/PoseStack;F)V";
var NUM_FOUND=0;
var NUM_PATCHED=0;
function log(message){
	print("[GenderCore]: "+message);
}
function initializeCoreMod(){
	return{
		"GenderCore-PlayerRenderer":{
			"target":{"type":"CLASS",'name':'net.minecraft.client.renderer.entity.player.PlayerRenderer'},
			"transformer": function(classNode){
				for each(var method in classNode.methods){
					if(method.name.equals(M0)&&method.desc.equals(M0_DESC)){
						NUM_FOUND++;
						var toInject=new InsnList();
						toInject.add(new VarInsnNode(Opcodes.ALOAD,1));
						toInject.add(new VarInsnNode(Opcodes.ALOAD,2));
						toInject.add(new MethodInsnNode(Opcodes.INVOKESTATIC,"com/github/ipixeli/gender/forge/client/GenderClient","onEvent","(Lnet/minecraft/world/entity/player/Player;Lcom/mojang/blaze3d/vertex/PoseStack;)V"));
						toInject.add(new InsnNode(Opcodes.RETURN));
						method.instructions=toInject;
						NUM_PATCHED++;
					}//else if(method.name.equals("M0")) log(classNode.name+" - Didn't quite match: "+method.name+method.desc);
				}
				log("Found methods: "+NUM_FOUND+" of 1; Patched methods: "+NUM_PATCHED+" of 1");
				return classNode;
			}
		}
	};
}
